@@ -1,7 +1,7 @@
 package App::hr;
 
-our $DATE = '2015-07-30'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2015-08-19'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use feature 'say';
 use strict 'subs', 'vars';
@@ -193,7 +193,7 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.19 of App::hr (from Perl distribution App-hr), released on 2015-07-30.
+This document describes version 0.20 of App::hr (from Perl distribution App-hr), released on 2015-08-19.
 
 =head1 SYNOPSIS
 
@@ -214,6 +214,10 @@ You can also use the provided CLI L<hr>.
 
 =for Pod::Coverage ^(pick)$
 
+=head1 SEE ALSO
+
+L<ruler> (L<App::ruler>)
+
 =head1 FUNCTIONS
 
 =head2 hr([ PATTERN [, COLOR ] ]) => optional STR
